@@ -1,12 +1,23 @@
-import sys
 from abc import ABC, abstractmethod
+from string import punctuation
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.mapping.statements import EvaluatedStatement
-from t2wml.utils.bindings import update_bindings
+from t2wml.utils.bindings import update_bindings, bindings
 from t2wml.parsing.yaml_parsing import validate_yaml, Template
 from t2wml.parsing.region import YamlRegion
+from t2wml.parsing.clean_yaml_parsing import get_cleaned_dataframe
 from t2wml.spreadsheets.conversions import to_excel
 
+def string_is_valid(text: str) -> bool:
+    def check_special_characters(text: str) -> bool:
+        return all(char in punctuation for char in str(text))
+    if text is None or check_special_characters(text):
+        return False
+    text = text.strip().lower()
+    if text in ["", "#na", "nan"]:
+        return False
+    return True
+
 
 class StatementMapper(ABC):
     """an abstract class for creating statementmapper classes. refer to the api documentation for more details.
@@ -30,22 +41,20 @@ class StatementMapper(ABC):
             "data_file": sheet.data_file_name,
             "sheet_name": sheet.name,
         }
-        try:
-            metadata["created_by"] = self.created_by
-        except:
-            pass
+
         for col, row in self.iterator():
-            cell = to_excel(col-1, row-1)
-            try:
-                statement, inner_errors = self.get_cell_statement(
-                    sheet, wikifier, col, row, do_init=False)
-                statements[cell] = statement
-                if inner_errors:
-                    cell_errors[cell] = inner_errors
-            except T2WMLExceptions.TemplateDidNotApplyToInput as e:
-                cell_errors[cell] = e.errors
-            except Exception as e:
-                cell_errors[cell] = str(e)
+            if string_is_valid(str(bindings.excel_sheet[row-1][col-1])):
+                cell = to_excel(col-1, row-1)
+                try:
+                    statement, inner_errors = self.get_cell_statement(
+                        sheet, wikifier, col, row, do_init=False)
+                    statements[cell] = statement
+                    if inner_errors:
+                        cell_errors[cell] = inner_errors
+                except T2WMLExceptions.TemplateDidNotApplyToInput as e:
+                    cell_errors[cell] = e.errors
+                except Exception as e:
+                    cell_errors[cell] = {"fatal":str(e)}
 
         return statements, cell_errors, metadata
 
@@ -56,10 +65,11 @@ class YamlMapper(StatementMapper):
     def __init__(self, file_path):
         self.file_path = file_path
         self.yaml_data = validate_yaml(file_path)
-        self.created_by = self.yaml_data['statementMapping'].get(
-            'created_by', 't2wml')
 
     def do_init(self, sheet, wikifier):
+        if self.yaml_data.get("cleaningMapping"):
+            new_df=get_cleaned_dataframe(sheet, self.yaml_data["cleaningMapping"])
+            sheet.cleaned_data=new_df
         update_bindings(item_table=wikifier.item_table, sheet=sheet)
         
 
